@@ -72,6 +72,8 @@ extern "C" {
 
 struct sockaddr_internet;
 
+typedef struct sockaddr *sockaddr_t;
+
 /**
  * An object that holds ipv4 or ipv6 binary encoded host addresses.
  */
@@ -1737,6 +1739,130 @@ public:
     TCPServer(const char *address, const char *service, unsigned backlog = 5);
 };
 
+/**
+ * Helper function for linked_pointer<struct sockaddr>.
+ */
+__EXPORT struct addrinfo *_nextaddrinfo(struct addrinfo *addrinfo);
+
+/**
+ * Helper function for linked_pointer<struct sockaddr>.
+ */
+__EXPORT struct sockaddr *_getaddrinfo(struct addrinfo *addrinfo);
+
+/**
+ * Helper function for linked_pointer<struct sockaddr>.
+ */
+__EXPORT socket_t _getaddrsock(struct addrinfo *addrinfo);
+
+/**
+ * Linked pointer for address lists.  This can be used to iterate through
+ * the list of a Socket::address object using the linked_pointer method.
+ * @author David Sugar <dyfet@gnutelephony.org>
+ */
+template <>
+class linked_pointer<struct sockaddr>
+{
+private:
+    struct addrinfo *ptr;
+
+public:
+    inline linked_pointer(struct addrinfo *list)
+        {ptr = list;}
+
+    inline linked_pointer()
+        {ptr = NULL;}
+
+    inline linked_pointer(Socket::address& list)
+        {ptr = list.getList();};
+
+    /**
+     * Get the full socket address list by casted reference.
+     * @return addrinfo list we resolved or NULL if none.
+     */
+    inline operator struct sockaddr *() const
+        {return _getaddrinfo(ptr);};
+
+    /**
+     * Return the full socket address list by pointer reference.
+     * @return addrinfo list we resolved or NULL if none.
+     */
+    inline struct sockaddr *operator*() const
+        {return _getaddrinfo(ptr);};
+
+    inline operator struct sockaddr_in *() const
+        {return (struct sockaddr_in *)_getaddrinfo(ptr);};
+
+    inline struct sockaddr_in *in(void) const
+        {return (struct sockaddr_in *)_getaddrinfo(ptr);};
+
+#ifdef  AF_INET6
+    inline operator struct sockaddr_in6 *() const
+        {return (struct sockaddr_in6 *)_getaddrinfo(ptr);};
+
+    inline struct sockaddr_in6 *in6(void) const
+        {return (struct sockaddr_in6 *)_getaddrinfo(ptr);};
+#endif
+
+    /**
+     * Get socket as expression operator.
+     */
+    inline socket_t operator()(void) const
+        {return _getaddrsock(ptr);};
+
+    /**
+     * Test if the address list is valid.
+     * @return true if we have an address list.
+     */
+    inline operator bool() const
+        {return ptr != NULL;};
+
+    /**
+     * Assign our pointer from an address list.
+     * @param pointer of linked list.
+     */
+    inline void operator=(struct addrinfo *list)
+        {ptr = list;};
+
+    /**
+     * Assign our pointer from an address list.
+     * @param pointer of linked list.
+     */
+    inline void operator=(Socket::address& list)
+        {ptr = list.getList();};
+
+    /**
+     * Assign our pointer from an address list.
+     * @param pointer of linked list.
+     */
+    inline void set(struct addrinfo *list)
+        {ptr = list;};
+
+    /**
+     * Assign our pointer from an address list.
+     * @param pointer of linked list.
+     */
+    inline void set(Socket::address& list)
+        {ptr = list.getList();};
+
+
+    /**
+     * Return member from typed object our pointer references.
+     * @return evaluated member of object we point to.
+     */
+    inline struct sockaddr* operator->() const
+        {return _getaddrinfo(ptr);};
+
+    /**
+     * Test if we have no address list.
+     * @return true if we have no address list.
+     */
+    inline bool operator!() const
+        {return ptr == NULL;};
+
+    inline void next(void)
+        {ptr = _nextaddrinfo(ptr);};
+};
+
 /**
  * A convenience class for socket.
  */
@@ -1797,6 +1923,7 @@ String str(Socket& so, strsize_t size);
 
 typedef TCPServer   tcpserv_t;
 
+
 END_NAMESPACE
 
 #endif
